@@ -39,7 +39,7 @@ except ImportError:
     Iterable = (list, dict, tuple)
 
 from sure.registry import context as _registry
-version = '0.10.1'
+version = '0.10.2'
 
 
 def _get_file_name(func):
@@ -296,7 +296,7 @@ class that(object):
         if isinstance(comparison, bool):
             return comparison
 
-        raise comparison.as_assertion(), deep.explanation
+        raise comparison.as_assertion(self._src, dst)
 
     def equals(self, dst):
         if self._attribute and is_iterable(self._src):
@@ -374,7 +374,7 @@ class that(object):
             error = 'the length of the %s should be greater then %d, but is %d' % (
                 type(self._src).__name__,
                 that,
-                length
+                length,
             )
             raise AssertionError(error)
 
@@ -617,6 +617,7 @@ def word_to_number(word):
             'sure supports only literal numbers from one to twelve, ' \
             'you tried the word "twenty"')
 
+
 def action_for(context, provides=None, depends_on=None):
     if not provides:
         provides = []
